@@ -11,28 +11,29 @@ import           Development.IDE             hiding (pluginHandlers)
 import           Ide.Plugin.Error            (PluginError (PluginInternalError, PluginInvalidParams))
 import           Ide.PluginUtils
 import           Ide.Types
-import           Language.LSP.Protocol.Lens  as L
+import qualified Language.LSP.Protocol.Lens  as L
 import           Language.LSP.Protocol.Types
 import           Prelude                     hiding (log)
 import           System.Directory
 import           System.Exit
 import           System.FilePath
-import           System.Process
+import           System.Process.ListLike
+import qualified System.Process.Text         as Process
 
 data Log
   = LogProcessInvocationFailure Int
-  | LogReadCreateProcessInfo String [String]
+  | LogReadCreateProcessInfo T.Text [String]
   | LogInvalidInvocationInfo
   | LogCabalFmtNotFound
   deriving (Show)
 
 instance Pretty Log where
   pretty = \case
-    LogProcessInvocationFailure code -> "Invocation of cabal-fmt failed with code" <+> pretty code
+    LogProcessInvocationFailure exitCode -> "Invocation of cabal-fmt failed with code" <+> pretty exitCode
     LogReadCreateProcessInfo stdErrorOut args ->
       vcat $
         ["Invocation of cabal-fmt with arguments" <+> pretty args]
-          ++ ["failed with standard error:" <+> pretty stdErrorOut | not (null stdErrorOut)]
+          ++ ["failed with standard error:" <+> pretty stdErrorOut | not (T.null stdErrorOut)]
     LogInvalidInvocationInfo -> "Invocation of cabal-fmt with range was called but is not supported."
     LogCabalFmtNotFound -> "Couldn't find executable 'cabal-fmt'"
 
@@ -50,24 +51,24 @@ provider recorder _ (FormatRange _) _ _ _ = do
   logWith recorder Info LogInvalidInvocationInfo
   throwError $ PluginInvalidParams "You cannot format a text-range using cabal-fmt."
 provider recorder _ide FormatText contents nfp opts = do
-  let cabalFmtArgs = [fp, "--indent", show tabularSize]
+  let cabalFmtArgs = [ "--indent", show tabularSize]
   x <- liftIO $ findExecutable "cabal-fmt"
   case x of
     Just _ -> do
       (exitCode, out, err) <-
-        liftIO $ readCreateProcessWithExitCode
+        liftIO $ Process.readCreateProcessWithExitCode
           ( proc "cabal-fmt" cabalFmtArgs
           )
             { cwd = Just $ takeDirectory fp
             }
-          ""
+          contents
       log Debug $ LogReadCreateProcessInfo err cabalFmtArgs
       case exitCode of
         ExitFailure code -> do
           log Error $ LogProcessInvocationFailure code
           throwError (PluginInternalError "Failed to invoke cabal-fmt")
         ExitSuccess -> do
-          let fmtDiff = makeDiffTextEdit contents (T.pack out)
+          let fmtDiff = makeDiffTextEdit contents out
           pure $ InL fmtDiff
     Nothing -> do
       log Error LogCabalFmtNotFound
